@@ -29,9 +29,6 @@ class Doc2Chunk(AnnotatorTransformer, AnnotatorProperties):
     ``StringType`` or ``ArrayType[StringType]`` (using setIsArray). Useful for
     annotators that require a CHUNK type input.
 
-    For more extended examples on document pre-processing see the
-    `Spark NLP Workshop <https://github.com/JohnSnowLabs/spark-nlp-workshop/blob/master/tutorials/Certification_Trainings/Public/2.Text_Preprocessing_with_SparkNLP_Annotators_Transformers.ipynb>`__.
-
     ====================== ======================
     Input Annotation types Output Annotation type
     ====================== ======================
